/common/ad_type_infos.proto

--- v16/common/ad_type_infos.proto  2024-05-29 16:00:42.000000000 +0000
+++ v17/common/ad_type_infos.proto  2024-05-29 16:00:49.000000000 +0000
@@ -653,8 +653,8 @@
   string path2 = 14;
 }

-// A discovery multi asset ad.
-message DiscoveryMultiAssetAdInfo {
+// A Demand Gen multi asset ad.
+message DemandGenMultiAssetAdInfo {
   // Marketing image assets to be used in the ad. Valid image types are GIF,
   // JPEG, and PNG. The minimum size is 600x314 and the aspect ratio must
   // be 1.91:1 (+-1%). Required if square_marketing_images is
@@ -697,8 +697,8 @@
   optional bool lead_form_only = 9;
 }

-// A discovery carousel ad.
-message DiscoveryCarouselAdInfo {
+// A Demand Gen carousel ad.
+message DemandGenCarouselAdInfo {
   // Required. The Advertiser/brand name.
   string business_name = 1 [(google.api.field_behavior) = REQUIRED];

@@ -716,12 +716,12 @@
   string call_to_action_text = 5;

   // Required. Carousel cards that will display with the ad. Min 2 max 10.
-  repeated AdDiscoveryCarouselCardAsset carousel_cards = 6
+  repeated AdDemandGenCarouselCardAsset carousel_cards = 6
       [(google.api.field_behavior) = REQUIRED];
 }

-// A discovery video responsive ad.
-message DiscoveryVideoResponsiveAdInfo {
+// A Demand Gen video responsive ad.
+message DemandGenVideoResponsiveAdInfo {
   // List of text assets used for the short headline.
   repeated AdTextAsset headlines = 1;